/* gtkcomboboxgrid.h - GtkComboBoxGrid widget header
 *
 * Authors:            Jody Goldberg <jgoldberg@home.com>
 *                     Kristian Rietveld <kristian@planet.nl>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GTK_COMBO_BOX_GRID_H__
#define __GTK_COMBO_BOX_GRID_H__

#include "gtkcombobox.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define GTK_TYPE_COMBO_BOX_GRID           (gtk_combo_box_grid_get_type ())
#define GTK_COMBO_BOX_GRID(object)        (GTK_CHECK_CAST ((object), GTK_TYPE_COMBO_BOX_GRID, GtkComboBoxGrid))
#define GTK_COMBO_BOX_GRID_CLASS(klass)   (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_COMBO_BOX_GRID))
#define GTK_IS_COMBO_BOX_GRID(object)     (GTK_CHECK_TYPE ((object), GTK_TYPE_COMBO_BOX_GRID))
#define GTK_IS_COMBO_BOX_GRID_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_COMBO_BOX_GRID))

typedef struct _GtkComboBoxGridClass      GtkComboBoxGridClass;
typedef struct _GtkComboBoxGridItem       GtkComboBoxGridItem;
typedef struct _GtkComboBoxGrid           GtkComboBoxGrid;

struct _GtkComboBoxGridItem;
  
struct _GtkComboBoxGrid
{
  /*< private >*/
  GtkComboBox           parent_instance;
  
  int                   cols, rows;
  int                   number_of_elements;
  GList                *box_items;
  GtkComboBoxGridItem  *selected;
  
  GtkWidget            *table;
  GtkWidget            *preview_button;
};

struct _GtkComboBoxGridClass
{
  GtkComboBoxClass  parent_class;
  
  void  (*select) (GtkComboBoxGrid  *cboxgrid,
		   GtkWidget        *item);
};

GtkType    gtk_combo_box_grid_get_type            (void);
GtkWidget *gtk_combo_box_grid_new                 (void);
void       gtk_combo_box_grid_add_item            (GtkComboBoxGrid *cboxgrid,
						   GtkWidget       *widget);
GtkWidget *gtk_combo_box_grid_get_selected        (GtkComboBoxGrid *cboxgrid);
void       gtk_combo_box_grid_remove_item         (GtkComboBoxGrid *cboxgrid,
						   GtkWidget       *item);
void       gtk_combo_box_grid_select_item         (GtkComboBoxGrid *cboxgrid,
						   GtkWidget       *item);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GTK_COMBO_BOX_GRID_H__ */
